@@ -4,6 +4,8 @@ pub mod aa_tree;
 pub mod abstract_structs;
 pub mod argsort;
 pub mod array_compression;
+pub mod avl_tree;
+pub mod avl_tree_node;
 pub mod binary_search;
 pub mod bitwise;
 pub mod carmichael_number;
@@ -39,6 +41,8 @@ pub mod primality_test_miller_rabin;
 pub mod prime_number;
 pub mod segment_tree;
 pub mod segment_tree_dynamic;
+pub mod segment_tree_lazy;
+pub mod set_theory;
 pub mod sieve_of_eratosthenes;
 pub mod sort;
 pub mod sparse_table;
