@@ -6,11 +6,6 @@ pub trait Modulus {
 
 pub trait IsPrime: Modulus {}
 
-pub struct Add;
-impl crate::group_theory::BinaryOperationIdentifier for Add {}
-pub struct Mul;
-impl crate::group_theory::BinaryOperationIdentifier for Mul {}
-
 #[derive(Debug, Clone, Copy, PartialEq, Eq)]
 pub struct Modular<M: Modulus> {
     phantom: std::marker::PhantomData<M>,
@@ -39,25 +34,18 @@ impl<M: Modulus> From<usize> for Modular<M> {
     fn from(value: usize) -> Self { Self::new(value) }
 }
 
-impl<M: Modulus> group_theory::Identity<Add> for Modular<M> {
+impl<M: Modulus + std::marker::Copy> group_theory::Identity<group_theory::Additive> for Modular<M> {
     fn identity() -> Self { 0.into() }
 }
 
-impl<M: Modulus> group_theory::Identity<Mul> for Modular<M> {
+impl<M: Modulus + std::marker::Copy> group_theory::Identity<group_theory::Multiplicative>
+    for Modular<M>
+{
     fn identity() -> Self { 1.into() }
 }
 
-impl<M: Modulus> group_theory::BinaryOperation<Add> for Modular<M> {
-    fn operate(lhs: &Self, rhs: &Self) -> Self { (lhs.value + rhs.value).into() }
-}
-
-impl<M: Modulus> group_theory::Associative<Add> for Modular<M> {}
-
-impl<M: Modulus> group_theory::BinaryOperation<Mul> for Modular<M> {
-    fn operate(lhs: &Self, rhs: &Self) -> Self { (lhs.value * rhs.value).into() }
-}
-
-impl<M: Modulus> group_theory::Associative<Mul> for Modular<M> {}
+// impl<M: Modulus> group_theory::Associative<Mul> for
+// Modular<M> {}
 
 impl<M: Modulus + Copy> std::ops::AddAssign<Self> for Modular<M> {
     fn add_assign(&mut self, rhs: Self) { *self = *self + rhs; }
@@ -95,15 +83,17 @@ impl<M: Modulus + Copy> std::ops::MulAssign<Self> for Modular<M> {
     fn mul_assign(&mut self, rhs: Self) { *self = *self * rhs; }
 }
 
-impl<M: Modulus> Modular<M> {
-    pub fn pow(&self, exponent: usize) -> Self { <Self as power::Power<Mul>>::pow(self, exponent) }
+impl<M: Modulus + std::marker::Copy> Modular<M> {
+    pub fn pow(&self, exponent: usize) -> Self {
+        <Self as power::Power<group_theory::Multiplicative>>::pow(self, exponent)
+    }
 }
 
-impl<M: Modulus + IsPrime> Modular<M> {
+impl<M: Modulus + IsPrime + std::marker::Copy> Modular<M> {
     pub fn invert(&self) -> Self { self.pow(M::value() - 2) }
 }
 
-impl<M: Modulus + IsPrime> std::ops::Div<Self> for Modular<M> {
+impl<M: Modulus + IsPrime + std::marker::Copy> std::ops::Div<Self> for Modular<M> {
     type Output = Self;
 
     fn div(self, rhs: Self) -> Self { self * rhs.invert() }
